@@ -43,15 +43,15 @@ public:
     // (if fromSelection doesn't have a pixmap, it will only recreate the region)
     kpToolSelectionCreateCommand (const QString &name, const kpAbstractSelection &fromSelection,
                                   kpCommandEnvironment *environ);
-    virtual ~kpToolSelectionCreateCommand ();
+    ~kpToolSelectionCreateCommand () override;
 
-    virtual kpCommandSize::SizeType size () const;
+    kpCommandSize::SizeType size () const override;
 
     const kpAbstractSelection *fromSelection () const;
     void setFromSelection (const kpAbstractSelection &fromSelection);
 
-    virtual void execute ();
-    virtual void unexecute ();
+    void execute () override;
+    void unexecute () override;
 
 private:
     kpAbstractSelection *m_fromSelection;
