@@ -45,14 +45,14 @@ class kpToolSelectionMoveCommand : public kpNamedCommand
 {
 public:
     kpToolSelectionMoveCommand (const QString &name, kpCommandEnvironment *environ);
-    virtual ~kpToolSelectionMoveCommand ();
+    ~kpToolSelectionMoveCommand () override;
 
     kpAbstractSelection *originalSelectionClone () const;
 
-    kpCommandSize::SizeType size () const Q_DECL_OVERRIDE;
+    kpCommandSize::SizeType size () const override;
 
-    void execute () Q_DECL_OVERRIDE;
-    void unexecute () Q_DECL_OVERRIDE;
+    void execute () override;
+    void unexecute () override;
 
     void moveTo (const QPoint &point, bool moveLater = false);
     void moveTo (int x, int y, bool moveLater = false);
