@@ -54,9 +54,9 @@ public:
 
     kpEllipticalImageSelection &operator= (const kpEllipticalImageSelection &rhs);
 
-    virtual kpEllipticalImageSelection *clone () const;
+    kpEllipticalImageSelection *clone () const override;
 
-    virtual ~kpEllipticalImageSelection ();
+    ~kpEllipticalImageSelection () override;
 
 
 //
@@ -65,7 +65,7 @@ public:
 
 public:
     static const int SerialID = 1;
-    virtual int serialID () const;
+    int serialID () const override;
 
 
 //
@@ -73,7 +73,7 @@ public:
 //
 
 public:
-    virtual bool isRectangular () const;
+    bool isRectangular () const override;
 
 
 //
@@ -81,7 +81,7 @@ public:
 //
 
 public:
-   virtual QPolygon calculatePoints () const;
+   QPolygon calculatePoints () const override;
 
 
 //
@@ -89,7 +89,7 @@ public:
 //
 
 public:
-    virtual QRegion shapeRegion () const;
+    QRegion shapeRegion () const override;
 
 
 //
@@ -97,7 +97,7 @@ public:
 //
 
 public:
-    virtual bool contains (const QPoint &point) const;
+    bool contains (const QPoint &point) const override;
 
 
 //
@@ -105,8 +105,8 @@ public:
 //
 
 public:
-    virtual void paintBorder (QImage *destPixmap, const QRect &docRect,
-        bool selectionFinished) const;
+    void paintBorder (QImage *destPixmap, const QRect &docRect,
+        bool selectionFinished) const override;
 
 
 private:
