@@ -79,7 +79,7 @@ public:
    * Specifying <rows> and <columns> was made optional for KolourPaint.
    */
   kpColorCellsBase( QWidget *parent, int rows = 0, int columns = 0 );
-  ~kpColorCellsBase();
+  ~kpColorCellsBase() override;
 
 private:
   /** Added for KolourPaint. */
@@ -154,21 +154,21 @@ protected:
   /** Grays out the cells, when the object is disabled.
       Added for KolourPaint.
   */
-  void changeEvent( QEvent* event ) Q_DECL_OVERRIDE;
+  void changeEvent( QEvent* event ) override;
 
   // the three methods below are used to ensure equal column widths and row heights
   // for all cells and to update the widths/heights when the widget is resized
-  int sizeHintForColumn(int column) const Q_DECL_OVERRIDE;
-  int sizeHintForRow(int column) const Q_DECL_OVERRIDE;
-  void resizeEvent( QResizeEvent* event ) Q_DECL_OVERRIDE;
+  int sizeHintForColumn(int column) const override;
+  int sizeHintForRow(int column) const override;
+  void resizeEvent( QResizeEvent* event ) override;
 
-  void mouseReleaseEvent( QMouseEvent * ) Q_DECL_OVERRIDE;
-  void mousePressEvent( QMouseEvent * ) Q_DECL_OVERRIDE;
-  void mouseMoveEvent( QMouseEvent * ) Q_DECL_OVERRIDE;
-  void dragEnterEvent( QDragEnterEvent * ) Q_DECL_OVERRIDE;
-  void dragMoveEvent( QDragMoveEvent * ) Q_DECL_OVERRIDE;
-  void dropEvent( QDropEvent *) Q_DECL_OVERRIDE;
-  void mouseDoubleClickEvent( QMouseEvent * ) Q_DECL_OVERRIDE;
+  void mouseReleaseEvent( QMouseEvent * ) override;
+  void mousePressEvent( QMouseEvent * ) override;
+  void mouseMoveEvent( QMouseEvent * ) override;
+  void dragEnterEvent( QDragEnterEvent * ) override;
+  void dragMoveEvent( QDragMoveEvent * ) override;
+  void dropEvent( QDropEvent *) override;
+  void mouseDoubleClickEvent( QMouseEvent * ) override;
 
   /** <allowEmptyCell> was added for KolourPaint. */
   int positionToCell(const QPoint &pos, bool ignoreBorders=false,
