@@ -1,6 +1,6 @@
-
 /*
    Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
+   Copyright (c) 2017      Martin Koller <kollix@aon.at>
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
@@ -27,17 +27,21 @@
 
 
 #include "kpToolEllipse.h"
+#include "environments/tools/kpToolEnvironment.h"
+#include "imagelib/kpColor.h"
 
-#include "imagelib/kpPainter.h"
+#include <KLocalizedString>
 
-#include <klocale.h>
+#include <QPainter>
+#include <QPen>
+#include <QBrush>
 
 //---------------------------------------------------------------------
 
 kpToolEllipse::kpToolEllipse (kpToolEnvironment *environ, QObject *parent)
     : kpToolRectangularBase (i18n ("Ellipse"),
         i18n ("Draws ellipses and circles"),
-        &kpPainter::drawEllipse,
+        &kpToolEllipse::drawEllipse,
         Qt::Key_E,
         environ, parent, "tool_ellipse")
 {
@@ -45,3 +49,34 @@ kpToolEllipse::kpToolEllipse (kpToolEnvironment *environ, QObject *parent)
 
 //---------------------------------------------------------------------
 
+void kpToolEllipse::drawEllipse(kpImage *image,
+        int x, int y, int width, int height,
+        const kpColor &fcolor, int penWidth,
+        const kpColor &bcolor)
+{
+  if ( (width == 0) || (height == 0) )
+    return;
+
+  QPainter painter(image);
+  painter.setRenderHint(QPainter::Antialiasing, kpToolEnvironment::drawAntiAliased);
+
+  if ( ((2 * penWidth) > width) || ((2 * penWidth) > height) )
+    penWidth = qMin(width, height) / 2;
+
+  painter.setPen(QPen(fcolor.toQColor(), penWidth));
+
+  if ( bcolor.isValid() )
+    painter.setBrush(QBrush(bcolor.toQColor()));
+  else
+    painter.setBrush(Qt::NoBrush);
+
+  int offset = painter.testRenderHint(QPainter::Antialiasing) ? 1 : 0;
+
+  painter.drawEllipse(
+        x + penWidth / 2 + offset,
+        y + penWidth / 2 + offset,
+        qMax(1, width - penWidth - offset),
+        qMax(1, height - penWidth - offset));
+}
+
+//---------------------------------------------------------------------
