@@ -37,13 +37,13 @@ class kpToolEllipticalSelection : public kpAbstractImageSelectionTool
 {
 public:
     kpToolEllipticalSelection (kpToolSelectionEnvironment *environ, QObject *parent);
-    virtual ~kpToolEllipticalSelection ();
+    ~kpToolEllipticalSelection () override;
 
 protected:
     bool drawCreateMoreSelectionAndUpdateStatusBar (
         bool dragAccepted,
         const QPoint &accidentalDragAdjustedPoint,
-        const QRect &normalizedRect) Q_DECL_OVERRIDE;
+        const QRect &normalizedRect) override;
 };
 
 
