@@ -47,15 +47,15 @@ Q_OBJECT
 
 public:
     kpEffectBlurSharpenWidget (bool actOnSelection, QWidget *parent);
-    virtual ~kpEffectBlurSharpenWidget ();
+    ~kpEffectBlurSharpenWidget () override;
 
-    QString caption () const Q_DECL_OVERRIDE;
+    QString caption () const override;
 
-    bool isNoOp () const Q_DECL_OVERRIDE;
-    kpImage applyEffect (const kpImage &image) Q_DECL_OVERRIDE;
+    bool isNoOp () const override;
+    kpImage applyEffect (const kpImage &image) override;
 
     kpEffectCommandBase *createCommand (
-        kpCommandEnvironment *cmdEnviron) const Q_DECL_OVERRIDE;
+        kpCommandEnvironment *cmdEnviron) const override;
 
 protected slots:
     void slotUpdateTypeLabel ();
